# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class FacetResult(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        FacetResult - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'request_name': 'str',
            'request_field_name': 'str',
            'field_type': 'str',
            'request_type': 'str',
            'results': 'list[FacetResultItem]'
        }

        self.attribute_map = {
            'request_name': 'requestName',
            'request_field_name': 'requestFieldName',
            'field_type': 'fieldType',
            'request_type': 'requestType',
            'results': 'results'
        }

        self._request_name = None
        self._request_field_name = None
        self._field_type = None
        self._request_type = None
        self._results = None

    @property
    def request_name(self):
        """
        Gets the request_name of this FacetResult.
        This was the name passed in as part of the facetRequest

        :return: The request_name of this FacetResult.
        :rtype: str
        """
        return self._request_name

    @request_name.setter
    def request_name(self, request_name):
        """
        Sets the request_name of this FacetResult.
        This was the name passed in as part of the facetRequest

        :param request_name: The request_name of this FacetResult.
        :type: str
        """
        self._request_name = request_name

    @property
    def request_field_name(self):
        """
        Gets the request_field_name of this FacetResult.
        The field name that the facet was requested for.

        :return: The request_field_name of this FacetResult.
        :rtype: str
        """
        return self._request_field_name

    @request_field_name.setter
    def request_field_name(self, request_field_name):
        """
        Sets the request_field_name of this FacetResult.
        The field name that the facet was requested for.

        :param request_field_name: The request_field_name of this FacetResult.
        :type: str
        """
        self._request_field_name = request_field_name

    @property
    def field_type(self):
        """
        Gets the field_type of this FacetResult.
        data type of the field being returned (if this is a mixed field this will be unknown)

        :return: The field_type of this FacetResult.
        :rtype: str
        """
        return self._field_type

    @field_type.setter
    def field_type(self, field_type):
        """
        Sets the field_type of this FacetResult.
        data type of the field being returned (if this is a mixed field this will be unknown)

        :param field_type: The field_type of this FacetResult.
        :type: str
        """
        allowed_values = ["NUMBER", "STRING", "DATE", "BOOLEAN", "LIST", "GROUP"]
        if field_type not in allowed_values:
            raise ValueError(
                "Invalid value for `field_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._field_type = field_type

    @property
    def request_type(self):
        """
        Gets the request_type of this FacetResult.
        the facet request type that was made.

        :return: The request_type of this FacetResult.
        :rtype: str
        """
        return self._request_type

    @request_type.setter
    def request_type(self, request_type):
        """
        Sets the request_type of this FacetResult.
        the facet request type that was made.

        :param request_type: The request_type of this FacetResult.
        :type: str
        """
        allowed_values = ["TERM", "RANGE"]
        if request_type not in allowed_values:
            raise ValueError(
                "Invalid value for `request_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._request_type = request_type

    @property
    def results(self):
        """
        Gets the results of this FacetResult.


        :return: The results of this FacetResult.
        :rtype: list[FacetResultItem]
        """
        return self._results

    @results.setter
    def results(self, results):
        """
        Sets the results of this FacetResult.


        :param results: The results of this FacetResult.
        :type: list[FacetResultItem]
        """
        self._results = results

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class Condition(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Condition - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'type': 'str',
            'inverted': 'bool',
            'attribute_name': 'str',
            'value': 'str',
            'value_type': 'str',
            'operator': 'str',
            'codes': 'list[str]'
        }

        self.attribute_map = {
            'type': 'type',
            'inverted': 'inverted',
            'attribute_name': 'attributeName',
            'value': 'value',
            'value_type': 'valueType',
            'operator': 'operator',
            'codes': 'codes'
        }

        self._type = None
        self._inverted = False
        self._attribute_name = None
        self._value = None
        self._value_type = None
        self._operator = None
        self._codes = None

    @property
    def type(self):
        """
        Gets the type of this Condition.


        :return: The type of this Condition.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Condition.


        :param type: The type of this Condition.
        :type: str
        """
        self._type = type

    @property
    def inverted(self):
        """
        Gets the inverted of this Condition.


        :return: The inverted of this Condition.
        :rtype: bool
        """
        return self._inverted

    @inverted.setter
    def inverted(self, inverted):
        """
        Sets the inverted of this Condition.


        :param inverted: The inverted of this Condition.
        :type: bool
        """
        self._inverted = inverted

    @property
    def attribute_name(self):
        """
        Gets the attribute_name of this Condition.


        :return: The attribute_name of this Condition.
        :rtype: str
        """
        return self._attribute_name

    @attribute_name.setter
    def attribute_name(self, attribute_name):
        """
        Sets the attribute_name of this Condition.


        :param attribute_name: The attribute_name of this Condition.
        :type: str
        """
        self._attribute_name = attribute_name

    @property
    def value(self):
        """
        Gets the value of this Condition.


        :return: The value of this Condition.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this Condition.


        :param value: The value of this Condition.
        :type: str
        """
        self._value = value

    @property
    def value_type(self):
        """
        Gets the value_type of this Condition.


        :return: The value_type of this Condition.
        :rtype: str
        """
        return self._value_type

    @value_type.setter
    def value_type(self, value_type):
        """
        Sets the value_type of this Condition.


        :param value_type: The value_type of this Condition.
        :type: str
        """
        allowed_values = ["STRING", "NUMERIC", "DATETIME", "PERIOD"]
        if value_type not in allowed_values:
            raise ValueError(
                "Invalid value for `value_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._value_type = value_type

    @property
    def operator(self):
        """
        Gets the operator of this Condition.


        :return: The operator of this Condition.
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """
        Sets the operator of this Condition.


        :param operator: The operator of this Condition.
        :type: str
        """
        allowed_values = ["EQUALS", "LESS_THAN", "LESS_THAN_EQUALS", "GREATER_THAN", "GREATER_THAN_EQUALS", "CONTAINS", "BEGINS_WITH", "ENDS_WITH", "BEFORE", "AFTER"]
        if operator not in allowed_values:
            raise ValueError(
                "Invalid value for `operator`, must be one of {0}"
                .format(allowed_values)
            )
        self._operator = operator

    @property
    def codes(self):
        """
        Gets the codes of this Condition.


        :return: The codes of this Condition.
        :rtype: list[str]
        """
        return self._codes

    @codes.setter
    def codes(self, codes):
        """
        Sets the codes of this Condition.


        :param codes: The codes of this Condition.
        :type: list[str]
        """
        self._codes = codes

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class LockInfo(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        LockInfo - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'locked_by': 'UriReference',
            'date_created': 'datetime',
            'date_expires': 'datetime',
            'action': 'str'
        }

        self.attribute_map = {
            'locked_by': 'lockedBy',
            'date_created': 'dateCreated',
            'date_expires': 'dateExpires',
            'action': 'action'
        }

        self._locked_by = None
        self._date_created = None
        self._date_expires = None
        self._action = None

    @property
    def locked_by(self):
        """
        Gets the locked_by of this LockInfo.


        :return: The locked_by of this LockInfo.
        :rtype: UriReference
        """
        return self._locked_by

    @locked_by.setter
    def locked_by(self, locked_by):
        """
        Sets the locked_by of this LockInfo.


        :param locked_by: The locked_by of this LockInfo.
        :type: UriReference
        """
        self._locked_by = locked_by

    @property
    def date_created(self):
        """
        Gets the date_created of this LockInfo.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_created of this LockInfo.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this LockInfo.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_created: The date_created of this LockInfo.
        :type: datetime
        """
        self._date_created = date_created

    @property
    def date_expires(self):
        """
        Gets the date_expires of this LockInfo.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_expires of this LockInfo.
        :rtype: datetime
        """
        return self._date_expires

    @date_expires.setter
    def date_expires(self, date_expires):
        """
        Sets the date_expires of this LockInfo.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_expires: The date_expires of this LockInfo.
        :type: datetime
        """
        self._date_expires = date_expires

    @property
    def action(self):
        """
        Gets the action of this LockInfo.


        :return: The action of this LockInfo.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this LockInfo.


        :param action: The action of this LockInfo.
        :type: str
        """
        allowed_values = ["UPDATE", "DELETE", "COPY", "MOVE", "REPLACE", "THUMBNAIL", "TEXT_EXTRACTION"]
        if action not in allowed_values:
            raise ValueError(
                "Invalid value for `action`, must be one of {0}"
                .format(allowed_values)
            )
        self._action = action

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class Gistener(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Gistener - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'enabled': 'bool',
            'any_words': 'str',
            'all_words': 'str',
            'exclude_words': 'str',
            'exact_phrase': 'str',
            'group_tags': 'list[GroupTag]',
            'social_account': 'SocialAccount',
            'queue': 'Queue',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'enabled': 'enabled',
            'any_words': 'anyWords',
            'all_words': 'allWords',
            'exclude_words': 'excludeWords',
            'exact_phrase': 'exactPhrase',
            'group_tags': 'groupTags',
            'social_account': 'socialAccount',
            'queue': 'queue',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._date_created = None
        self._date_modified = None
        self._enabled = False
        self._any_words = None
        self._all_words = None
        self._exclude_words = None
        self._exact_phrase = None
        self._group_tags = None
        self._social_account = None
        self._queue = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Gistener.
        The globally unique identifier for the object.

        :return: The id of this Gistener.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Gistener.
        The globally unique identifier for the object.

        :param id: The id of this Gistener.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Gistener.


        :return: The name of this Gistener.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Gistener.


        :param name: The name of this Gistener.
        :type: str
        """
        self._name = name

    @property
    def date_created(self):
        """
        Gets the date_created of this Gistener.
        Creation date for the entity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_created of this Gistener.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this Gistener.
        Creation date for the entity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_created: The date_created of this Gistener.
        :type: datetime
        """
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this Gistener.
        Date the entity was last modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_modified of this Gistener.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this Gistener.
        Date the entity was last modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_modified: The date_modified of this Gistener.
        :type: datetime
        """
        self._date_modified = date_modified

    @property
    def enabled(self):
        """
        Gets the enabled of this Gistener.
        Indicates if this Gistener may be utilized on another entity

        :return: The enabled of this Gistener.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this Gistener.
        Indicates if this Gistener may be utilized on another entity

        :param enabled: The enabled of this Gistener.
        :type: bool
        """
        self._enabled = enabled

    @property
    def any_words(self):
        """
        Gets the any_words of this Gistener.
        A tweet must contain any one of these words

        :return: The any_words of this Gistener.
        :rtype: str
        """
        return self._any_words

    @any_words.setter
    def any_words(self, any_words):
        """
        Sets the any_words of this Gistener.
        A tweet must contain any one of these words

        :param any_words: The any_words of this Gistener.
        :type: str
        """
        self._any_words = any_words

    @property
    def all_words(self):
        """
        Gets the all_words of this Gistener.
        A tweet must contain every one of these words in any order

        :return: The all_words of this Gistener.
        :rtype: str
        """
        return self._all_words

    @all_words.setter
    def all_words(self, all_words):
        """
        Sets the all_words of this Gistener.
        A tweet must contain every one of these words in any order

        :param all_words: The all_words of this Gistener.
        :type: str
        """
        self._all_words = all_words

    @property
    def exclude_words(self):
        """
        Gets the exclude_words of this Gistener.
        If a tweet contains any one of these words, it is thrown out

        :return: The exclude_words of this Gistener.
        :rtype: str
        """
        return self._exclude_words

    @exclude_words.setter
    def exclude_words(self, exclude_words):
        """
        Sets the exclude_words of this Gistener.
        If a tweet contains any one of these words, it is thrown out

        :param exclude_words: The exclude_words of this Gistener.
        :type: str
        """
        self._exclude_words = exclude_words

    @property
    def exact_phrase(self):
        """
        Gets the exact_phrase of this Gistener.
        A tweet must contain this exact quoted phrase

        :return: The exact_phrase of this Gistener.
        :rtype: str
        """
        return self._exact_phrase

    @exact_phrase.setter
    def exact_phrase(self, exact_phrase):
        """
        Sets the exact_phrase of this Gistener.
        A tweet must contain this exact quoted phrase

        :param exact_phrase: The exact_phrase of this Gistener.
        :type: str
        """
        self._exact_phrase = exact_phrase

    @property
    def group_tags(self):
        """
        Gets the group_tags of this Gistener.
        The group tags associated with this Gistener

        :return: The group_tags of this Gistener.
        :rtype: list[GroupTag]
        """
        return self._group_tags

    @group_tags.setter
    def group_tags(self, group_tags):
        """
        Sets the group_tags of this Gistener.
        The group tags associated with this Gistener

        :param group_tags: The group_tags of this Gistener.
        :type: list[GroupTag]
        """
        self._group_tags = group_tags

    @property
    def social_account(self):
        """
        Gets the social_account of this Gistener.
        The social account associated with this Gistener

        :return: The social_account of this Gistener.
        :rtype: SocialAccount
        """
        return self._social_account

    @social_account.setter
    def social_account(self, social_account):
        """
        Sets the social_account of this Gistener.
        The social account associated with this Gistener

        :param social_account: The social_account of this Gistener.
        :type: SocialAccount
        """
        self._social_account = social_account

    @property
    def queue(self):
        """
        Gets the queue of this Gistener.
        The operator queue the gistener will route to.

        :return: The queue of this Gistener.
        :rtype: Queue
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """
        Sets the queue of this Gistener.
        The operator queue the gistener will route to.

        :param queue: The queue of this Gistener.
        :type: Queue
        """
        self._queue = queue

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Gistener.
        The URI for this object

        :return: The self_uri of this Gistener.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Gistener.
        The URI for this object

        :param self_uri: The self_uri of this Gistener.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class AnalyticsSession(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AnalyticsSession - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'media_type': 'str',
            'session_id': 'str',
            'address_other': 'str',
            'address_self': 'str',
            'ani': 'str',
            'direction': 'str',
            'dnis': 'str',
            'outbound_campaign_id': 'str',
            'outbound_contact_id': 'str',
            'outbound_contact_list_id': 'str',
            'disposition_analyzer': 'str',
            'disposition_name': 'str',
            'edge_id': 'str',
            'remote_name_displayable': 'str',
            'room_id': 'str',
            'monitored_session_id': 'str',
            'monitored_participant_id': 'str',
            'segments': 'list[AnalyticsConversationSegment]'
        }

        self.attribute_map = {
            'media_type': 'mediaType',
            'session_id': 'sessionId',
            'address_other': 'addressOther',
            'address_self': 'addressSelf',
            'ani': 'ani',
            'direction': 'direction',
            'dnis': 'dnis',
            'outbound_campaign_id': 'outboundCampaignId',
            'outbound_contact_id': 'outboundContactId',
            'outbound_contact_list_id': 'outboundContactListId',
            'disposition_analyzer': 'dispositionAnalyzer',
            'disposition_name': 'dispositionName',
            'edge_id': 'edgeId',
            'remote_name_displayable': 'remoteNameDisplayable',
            'room_id': 'roomId',
            'monitored_session_id': 'monitoredSessionId',
            'monitored_participant_id': 'monitoredParticipantId',
            'segments': 'segments'
        }

        self._media_type = None
        self._session_id = None
        self._address_other = None
        self._address_self = None
        self._ani = None
        self._direction = None
        self._dnis = None
        self._outbound_campaign_id = None
        self._outbound_contact_id = None
        self._outbound_contact_list_id = None
        self._disposition_analyzer = None
        self._disposition_name = None
        self._edge_id = None
        self._remote_name_displayable = None
        self._room_id = None
        self._monitored_session_id = None
        self._monitored_participant_id = None
        self._segments = None

    @property
    def media_type(self):
        """
        Gets the media_type of this AnalyticsSession.


        :return: The media_type of this AnalyticsSession.
        :rtype: str
        """
        return self._media_type

    @media_type.setter
    def media_type(self, media_type):
        """
        Sets the media_type of this AnalyticsSession.


        :param media_type: The media_type of this AnalyticsSession.
        :type: str
        """
        allowed_values = ["voice", "chat", "email"]
        if media_type not in allowed_values:
            raise ValueError(
                "Invalid value for `media_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._media_type = media_type

    @property
    def session_id(self):
        """
        Gets the session_id of this AnalyticsSession.


        :return: The session_id of this AnalyticsSession.
        :rtype: str
        """
        return self._session_id

    @session_id.setter
    def session_id(self, session_id):
        """
        Sets the session_id of this AnalyticsSession.


        :param session_id: The session_id of this AnalyticsSession.
        :type: str
        """
        self._session_id = session_id

    @property
    def address_other(self):
        """
        Gets the address_other of this AnalyticsSession.


        :return: The address_other of this AnalyticsSession.
        :rtype: str
        """
        return self._address_other

    @address_other.setter
    def address_other(self, address_other):
        """
        Sets the address_other of this AnalyticsSession.


        :param address_other: The address_other of this AnalyticsSession.
        :type: str
        """
        self._address_other = address_other

    @property
    def address_self(self):
        """
        Gets the address_self of this AnalyticsSession.


        :return: The address_self of this AnalyticsSession.
        :rtype: str
        """
        return self._address_self

    @address_self.setter
    def address_self(self, address_self):
        """
        Sets the address_self of this AnalyticsSession.


        :param address_self: The address_self of this AnalyticsSession.
        :type: str
        """
        self._address_self = address_self

    @property
    def ani(self):
        """
        Gets the ani of this AnalyticsSession.


        :return: The ani of this AnalyticsSession.
        :rtype: str
        """
        return self._ani

    @ani.setter
    def ani(self, ani):
        """
        Sets the ani of this AnalyticsSession.


        :param ani: The ani of this AnalyticsSession.
        :type: str
        """
        self._ani = ani

    @property
    def direction(self):
        """
        Gets the direction of this AnalyticsSession.


        :return: The direction of this AnalyticsSession.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this AnalyticsSession.


        :param direction: The direction of this AnalyticsSession.
        :type: str
        """
        allowed_values = ["inbound", "outbound"]
        if direction not in allowed_values:
            raise ValueError(
                "Invalid value for `direction`, must be one of {0}"
                .format(allowed_values)
            )
        self._direction = direction

    @property
    def dnis(self):
        """
        Gets the dnis of this AnalyticsSession.


        :return: The dnis of this AnalyticsSession.
        :rtype: str
        """
        return self._dnis

    @dnis.setter
    def dnis(self, dnis):
        """
        Sets the dnis of this AnalyticsSession.


        :param dnis: The dnis of this AnalyticsSession.
        :type: str
        """
        self._dnis = dnis

    @property
    def outbound_campaign_id(self):
        """
        Gets the outbound_campaign_id of this AnalyticsSession.


        :return: The outbound_campaign_id of this AnalyticsSession.
        :rtype: str
        """
        return self._outbound_campaign_id

    @outbound_campaign_id.setter
    def outbound_campaign_id(self, outbound_campaign_id):
        """
        Sets the outbound_campaign_id of this AnalyticsSession.


        :param outbound_campaign_id: The outbound_campaign_id of this AnalyticsSession.
        :type: str
        """
        self._outbound_campaign_id = outbound_campaign_id

    @property
    def outbound_contact_id(self):
        """
        Gets the outbound_contact_id of this AnalyticsSession.


        :return: The outbound_contact_id of this AnalyticsSession.
        :rtype: str
        """
        return self._outbound_contact_id

    @outbound_contact_id.setter
    def outbound_contact_id(self, outbound_contact_id):
        """
        Sets the outbound_contact_id of this AnalyticsSession.


        :param outbound_contact_id: The outbound_contact_id of this AnalyticsSession.
        :type: str
        """
        self._outbound_contact_id = outbound_contact_id

    @property
    def outbound_contact_list_id(self):
        """
        Gets the outbound_contact_list_id of this AnalyticsSession.


        :return: The outbound_contact_list_id of this AnalyticsSession.
        :rtype: str
        """
        return self._outbound_contact_list_id

    @outbound_contact_list_id.setter
    def outbound_contact_list_id(self, outbound_contact_list_id):
        """
        Sets the outbound_contact_list_id of this AnalyticsSession.


        :param outbound_contact_list_id: The outbound_contact_list_id of this AnalyticsSession.
        :type: str
        """
        self._outbound_contact_list_id = outbound_contact_list_id

    @property
    def disposition_analyzer(self):
        """
        Gets the disposition_analyzer of this AnalyticsSession.


        :return: The disposition_analyzer of this AnalyticsSession.
        :rtype: str
        """
        return self._disposition_analyzer

    @disposition_analyzer.setter
    def disposition_analyzer(self, disposition_analyzer):
        """
        Sets the disposition_analyzer of this AnalyticsSession.


        :param disposition_analyzer: The disposition_analyzer of this AnalyticsSession.
        :type: str
        """
        self._disposition_analyzer = disposition_analyzer

    @property
    def disposition_name(self):
        """
        Gets the disposition_name of this AnalyticsSession.


        :return: The disposition_name of this AnalyticsSession.
        :rtype: str
        """
        return self._disposition_name

    @disposition_name.setter
    def disposition_name(self, disposition_name):
        """
        Sets the disposition_name of this AnalyticsSession.


        :param disposition_name: The disposition_name of this AnalyticsSession.
        :type: str
        """
        self._disposition_name = disposition_name

    @property
    def edge_id(self):
        """
        Gets the edge_id of this AnalyticsSession.


        :return: The edge_id of this AnalyticsSession.
        :rtype: str
        """
        return self._edge_id

    @edge_id.setter
    def edge_id(self, edge_id):
        """
        Sets the edge_id of this AnalyticsSession.


        :param edge_id: The edge_id of this AnalyticsSession.
        :type: str
        """
        self._edge_id = edge_id

    @property
    def remote_name_displayable(self):
        """
        Gets the remote_name_displayable of this AnalyticsSession.


        :return: The remote_name_displayable of this AnalyticsSession.
        :rtype: str
        """
        return self._remote_name_displayable

    @remote_name_displayable.setter
    def remote_name_displayable(self, remote_name_displayable):
        """
        Sets the remote_name_displayable of this AnalyticsSession.


        :param remote_name_displayable: The remote_name_displayable of this AnalyticsSession.
        :type: str
        """
        self._remote_name_displayable = remote_name_displayable

    @property
    def room_id(self):
        """
        Gets the room_id of this AnalyticsSession.


        :return: The room_id of this AnalyticsSession.
        :rtype: str
        """
        return self._room_id

    @room_id.setter
    def room_id(self, room_id):
        """
        Sets the room_id of this AnalyticsSession.


        :param room_id: The room_id of this AnalyticsSession.
        :type: str
        """
        self._room_id = room_id

    @property
    def monitored_session_id(self):
        """
        Gets the monitored_session_id of this AnalyticsSession.


        :return: The monitored_session_id of this AnalyticsSession.
        :rtype: str
        """
        return self._monitored_session_id

    @monitored_session_id.setter
    def monitored_session_id(self, monitored_session_id):
        """
        Sets the monitored_session_id of this AnalyticsSession.


        :param monitored_session_id: The monitored_session_id of this AnalyticsSession.
        :type: str
        """
        self._monitored_session_id = monitored_session_id

    @property
    def monitored_participant_id(self):
        """
        Gets the monitored_participant_id of this AnalyticsSession.


        :return: The monitored_participant_id of this AnalyticsSession.
        :rtype: str
        """
        return self._monitored_participant_id

    @monitored_participant_id.setter
    def monitored_participant_id(self, monitored_participant_id):
        """
        Sets the monitored_participant_id of this AnalyticsSession.


        :param monitored_participant_id: The monitored_participant_id of this AnalyticsSession.
        :type: str
        """
        self._monitored_participant_id = monitored_participant_id

    @property
    def segments(self):
        """
        Gets the segments of this AnalyticsSession.


        :return: The segments of this AnalyticsSession.
        :rtype: list[AnalyticsConversationSegment]
        """
        return self._segments

    @segments.setter
    def segments(self, segments):
        """
        Sets the segments of this AnalyticsSession.


        :param segments: The segments of this AnalyticsSession.
        :type: list[AnalyticsConversationSegment]
        """
        self._segments = segments

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class VoicemailOrganizationPolicy(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        VoicemailOrganizationPolicy - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'enabled': 'bool',
            'retention_time_days': 'int',
            'alert_timeout_seconds': 'int',
            'minimum_recording_time_seconds': 'int',
            'maximum_recording_time_seconds': 'int',
            'unavailable_message_uri': 'str',
            'name_prompt_message_uri': 'str',
            'full_message_uri': 'str',
            'compress_silence': 'bool',
            'pin_configuration': 'PINConfiguration',
            'quota_size_bytes': 'int',
            'created_date': 'datetime',
            'modified_date': 'datetime',
            'voicemail_extension': 'str',
            'pin_required': 'bool'
        }

        self.attribute_map = {
            'enabled': 'enabled',
            'retention_time_days': 'retentionTimeDays',
            'alert_timeout_seconds': 'alertTimeoutSeconds',
            'minimum_recording_time_seconds': 'minimumRecordingTimeSeconds',
            'maximum_recording_time_seconds': 'maximumRecordingTimeSeconds',
            'unavailable_message_uri': 'unavailableMessageUri',
            'name_prompt_message_uri': 'namePromptMessageUri',
            'full_message_uri': 'fullMessageUri',
            'compress_silence': 'compressSilence',
            'pin_configuration': 'pinConfiguration',
            'quota_size_bytes': 'quotaSizeBytes',
            'created_date': 'createdDate',
            'modified_date': 'modifiedDate',
            'voicemail_extension': 'voicemailExtension',
            'pin_required': 'pinRequired'
        }

        self._enabled = False
        self._retention_time_days = None
        self._alert_timeout_seconds = None
        self._minimum_recording_time_seconds = None
        self._maximum_recording_time_seconds = None
        self._unavailable_message_uri = None
        self._name_prompt_message_uri = None
        self._full_message_uri = None
        self._compress_silence = False
        self._pin_configuration = None
        self._quota_size_bytes = None
        self._created_date = None
        self._modified_date = None
        self._voicemail_extension = None
        self._pin_required = False

    @property
    def enabled(self):
        """
        Gets the enabled of this VoicemailOrganizationPolicy.


        :return: The enabled of this VoicemailOrganizationPolicy.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this VoicemailOrganizationPolicy.


        :param enabled: The enabled of this VoicemailOrganizationPolicy.
        :type: bool
        """
        self._enabled = enabled

    @property
    def retention_time_days(self):
        """
        Gets the retention_time_days of this VoicemailOrganizationPolicy.


        :return: The retention_time_days of this VoicemailOrganizationPolicy.
        :rtype: int
        """
        return self._retention_time_days

    @retention_time_days.setter
    def retention_time_days(self, retention_time_days):
        """
        Sets the retention_time_days of this VoicemailOrganizationPolicy.


        :param retention_time_days: The retention_time_days of this VoicemailOrganizationPolicy.
        :type: int
        """
        self._retention_time_days = retention_time_days

    @property
    def alert_timeout_seconds(self):
        """
        Gets the alert_timeout_seconds of this VoicemailOrganizationPolicy.


        :return: The alert_timeout_seconds of this VoicemailOrganizationPolicy.
        :rtype: int
        """
        return self._alert_timeout_seconds

    @alert_timeout_seconds.setter
    def alert_timeout_seconds(self, alert_timeout_seconds):
        """
        Sets the alert_timeout_seconds of this VoicemailOrganizationPolicy.


        :param alert_timeout_seconds: The alert_timeout_seconds of this VoicemailOrganizationPolicy.
        :type: int
        """
        self._alert_timeout_seconds = alert_timeout_seconds

    @property
    def minimum_recording_time_seconds(self):
        """
        Gets the minimum_recording_time_seconds of this VoicemailOrganizationPolicy.


        :return: The minimum_recording_time_seconds of this VoicemailOrganizationPolicy.
        :rtype: int
        """
        return self._minimum_recording_time_seconds

    @minimum_recording_time_seconds.setter
    def minimum_recording_time_seconds(self, minimum_recording_time_seconds):
        """
        Sets the minimum_recording_time_seconds of this VoicemailOrganizationPolicy.


        :param minimum_recording_time_seconds: The minimum_recording_time_seconds of this VoicemailOrganizationPolicy.
        :type: int
        """
        self._minimum_recording_time_seconds = minimum_recording_time_seconds

    @property
    def maximum_recording_time_seconds(self):
        """
        Gets the maximum_recording_time_seconds of this VoicemailOrganizationPolicy.


        :return: The maximum_recording_time_seconds of this VoicemailOrganizationPolicy.
        :rtype: int
        """
        return self._maximum_recording_time_seconds

    @maximum_recording_time_seconds.setter
    def maximum_recording_time_seconds(self, maximum_recording_time_seconds):
        """
        Sets the maximum_recording_time_seconds of this VoicemailOrganizationPolicy.


        :param maximum_recording_time_seconds: The maximum_recording_time_seconds of this VoicemailOrganizationPolicy.
        :type: int
        """
        self._maximum_recording_time_seconds = maximum_recording_time_seconds

    @property
    def unavailable_message_uri(self):
        """
        Gets the unavailable_message_uri of this VoicemailOrganizationPolicy.


        :return: The unavailable_message_uri of this VoicemailOrganizationPolicy.
        :rtype: str
        """
        return self._unavailable_message_uri

    @unavailable_message_uri.setter
    def unavailable_message_uri(self, unavailable_message_uri):
        """
        Sets the unavailable_message_uri of this VoicemailOrganizationPolicy.


        :param unavailable_message_uri: The unavailable_message_uri of this VoicemailOrganizationPolicy.
        :type: str
        """
        self._unavailable_message_uri = unavailable_message_uri

    @property
    def name_prompt_message_uri(self):
        """
        Gets the name_prompt_message_uri of this VoicemailOrganizationPolicy.


        :return: The name_prompt_message_uri of this VoicemailOrganizationPolicy.
        :rtype: str
        """
        return self._name_prompt_message_uri

    @name_prompt_message_uri.setter
    def name_prompt_message_uri(self, name_prompt_message_uri):
        """
        Sets the name_prompt_message_uri of this VoicemailOrganizationPolicy.


        :param name_prompt_message_uri: The name_prompt_message_uri of this VoicemailOrganizationPolicy.
        :type: str
        """
        self._name_prompt_message_uri = name_prompt_message_uri

    @property
    def full_message_uri(self):
        """
        Gets the full_message_uri of this VoicemailOrganizationPolicy.


        :return: The full_message_uri of this VoicemailOrganizationPolicy.
        :rtype: str
        """
        return self._full_message_uri

    @full_message_uri.setter
    def full_message_uri(self, full_message_uri):
        """
        Sets the full_message_uri of this VoicemailOrganizationPolicy.


        :param full_message_uri: The full_message_uri of this VoicemailOrganizationPolicy.
        :type: str
        """
        self._full_message_uri = full_message_uri

    @property
    def compress_silence(self):
        """
        Gets the compress_silence of this VoicemailOrganizationPolicy.


        :return: The compress_silence of this VoicemailOrganizationPolicy.
        :rtype: bool
        """
        return self._compress_silence

    @compress_silence.setter
    def compress_silence(self, compress_silence):
        """
        Sets the compress_silence of this VoicemailOrganizationPolicy.


        :param compress_silence: The compress_silence of this VoicemailOrganizationPolicy.
        :type: bool
        """
        self._compress_silence = compress_silence

    @property
    def pin_configuration(self):
        """
        Gets the pin_configuration of this VoicemailOrganizationPolicy.


        :return: The pin_configuration of this VoicemailOrganizationPolicy.
        :rtype: PINConfiguration
        """
        return self._pin_configuration

    @pin_configuration.setter
    def pin_configuration(self, pin_configuration):
        """
        Sets the pin_configuration of this VoicemailOrganizationPolicy.


        :param pin_configuration: The pin_configuration of this VoicemailOrganizationPolicy.
        :type: PINConfiguration
        """
        self._pin_configuration = pin_configuration

    @property
    def quota_size_bytes(self):
        """
        Gets the quota_size_bytes of this VoicemailOrganizationPolicy.


        :return: The quota_size_bytes of this VoicemailOrganizationPolicy.
        :rtype: int
        """
        return self._quota_size_bytes

    @quota_size_bytes.setter
    def quota_size_bytes(self, quota_size_bytes):
        """
        Sets the quota_size_bytes of this VoicemailOrganizationPolicy.


        :param quota_size_bytes: The quota_size_bytes of this VoicemailOrganizationPolicy.
        :type: int
        """
        self._quota_size_bytes = quota_size_bytes

    @property
    def created_date(self):
        """
        Gets the created_date of this VoicemailOrganizationPolicy.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The created_date of this VoicemailOrganizationPolicy.
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """
        Sets the created_date of this VoicemailOrganizationPolicy.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param created_date: The created_date of this VoicemailOrganizationPolicy.
        :type: datetime
        """
        self._created_date = created_date

    @property
    def modified_date(self):
        """
        Gets the modified_date of this VoicemailOrganizationPolicy.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The modified_date of this VoicemailOrganizationPolicy.
        :rtype: datetime
        """
        return self._modified_date

    @modified_date.setter
    def modified_date(self, modified_date):
        """
        Sets the modified_date of this VoicemailOrganizationPolicy.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param modified_date: The modified_date of this VoicemailOrganizationPolicy.
        :type: datetime
        """
        self._modified_date = modified_date

    @property
    def voicemail_extension(self):
        """
        Gets the voicemail_extension of this VoicemailOrganizationPolicy.
        The extension for voicemail retrieval.  The default value is *86.

        :return: The voicemail_extension of this VoicemailOrganizationPolicy.
        :rtype: str
        """
        return self._voicemail_extension

    @voicemail_extension.setter
    def voicemail_extension(self, voicemail_extension):
        """
        Sets the voicemail_extension of this VoicemailOrganizationPolicy.
        The extension for voicemail retrieval.  The default value is *86.

        :param voicemail_extension: The voicemail_extension of this VoicemailOrganizationPolicy.
        :type: str
        """
        self._voicemail_extension = voicemail_extension

    @property
    def pin_required(self):
        """
        Gets the pin_required of this VoicemailOrganizationPolicy.
        If this is true, a PIN is required when accessing a user's voicemail from a phone.

        :return: The pin_required of this VoicemailOrganizationPolicy.
        :rtype: bool
        """
        return self._pin_required

    @pin_required.setter
    def pin_required(self, pin_required):
        """
        Sets the pin_required of this VoicemailOrganizationPolicy.
        If this is true, a PIN is required when accessing a user's voicemail from a phone.

        :param pin_required: The pin_required of this VoicemailOrganizationPolicy.
        :type: bool
        """
        self._pin_required = pin_required

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class AnalyticsConversationSegment(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AnalyticsConversationSegment - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'segment_start': 'datetime',
            'segment_end': 'datetime',
            'queue_id': 'str',
            'wrap_up_code': 'str',
            'wrap_up_note': 'str',
            'wrap_up_tags': 'list[str]',
            'error_code': 'str',
            'disconnect_type': 'str',
            'segment_type': 'str',
            'requested_routing_user_ids': 'list[str]',
            'requested_routing_skill_ids': 'list[str]',
            'requested_language_id': 'str',
            'properties': 'list[AnalyticsProperty]',
            'source_conversation_id': 'str',
            'destination_conversation_id': 'str',
            'source_session_id': 'str',
            'destination_session_id': 'str',
            'sip_response_codes': 'list[int]',
            'q850_response_codes': 'list[int]',
            'conference': 'bool',
            'group_id': 'str',
            'subject': 'str'
        }

        self.attribute_map = {
            'segment_start': 'segmentStart',
            'segment_end': 'segmentEnd',
            'queue_id': 'queueId',
            'wrap_up_code': 'wrapUpCode',
            'wrap_up_note': 'wrapUpNote',
            'wrap_up_tags': 'wrapUpTags',
            'error_code': 'errorCode',
            'disconnect_type': 'disconnectType',
            'segment_type': 'segmentType',
            'requested_routing_user_ids': 'requestedRoutingUserIds',
            'requested_routing_skill_ids': 'requestedRoutingSkillIds',
            'requested_language_id': 'requestedLanguageId',
            'properties': 'properties',
            'source_conversation_id': 'sourceConversationId',
            'destination_conversation_id': 'destinationConversationId',
            'source_session_id': 'sourceSessionId',
            'destination_session_id': 'destinationSessionId',
            'sip_response_codes': 'sipResponseCodes',
            'q850_response_codes': 'q850ResponseCodes',
            'conference': 'conference',
            'group_id': 'groupId',
            'subject': 'subject'
        }

        self._segment_start = None
        self._segment_end = None
        self._queue_id = None
        self._wrap_up_code = None
        self._wrap_up_note = None
        self._wrap_up_tags = None
        self._error_code = None
        self._disconnect_type = None
        self._segment_type = None
        self._requested_routing_user_ids = None
        self._requested_routing_skill_ids = None
        self._requested_language_id = None
        self._properties = None
        self._source_conversation_id = None
        self._destination_conversation_id = None
        self._source_session_id = None
        self._destination_session_id = None
        self._sip_response_codes = None
        self._q850_response_codes = None
        self._conference = False
        self._group_id = None
        self._subject = None

    @property
    def segment_start(self):
        """
        Gets the segment_start of this AnalyticsConversationSegment.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The segment_start of this AnalyticsConversationSegment.
        :rtype: datetime
        """
        return self._segment_start

    @segment_start.setter
    def segment_start(self, segment_start):
        """
        Sets the segment_start of this AnalyticsConversationSegment.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param segment_start: The segment_start of this AnalyticsConversationSegment.
        :type: datetime
        """
        self._segment_start = segment_start

    @property
    def segment_end(self):
        """
        Gets the segment_end of this AnalyticsConversationSegment.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The segment_end of this AnalyticsConversationSegment.
        :rtype: datetime
        """
        return self._segment_end

    @segment_end.setter
    def segment_end(self, segment_end):
        """
        Sets the segment_end of this AnalyticsConversationSegment.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param segment_end: The segment_end of this AnalyticsConversationSegment.
        :type: datetime
        """
        self._segment_end = segment_end

    @property
    def queue_id(self):
        """
        Gets the queue_id of this AnalyticsConversationSegment.


        :return: The queue_id of this AnalyticsConversationSegment.
        :rtype: str
        """
        return self._queue_id

    @queue_id.setter
    def queue_id(self, queue_id):
        """
        Sets the queue_id of this AnalyticsConversationSegment.


        :param queue_id: The queue_id of this AnalyticsConversationSegment.
        :type: str
        """
        self._queue_id = queue_id

    @property
    def wrap_up_code(self):
        """
        Gets the wrap_up_code of this AnalyticsConversationSegment.


        :return: The wrap_up_code of this AnalyticsConversationSegment.
        :rtype: str
        """
        return self._wrap_up_code

    @wrap_up_code.setter
    def wrap_up_code(self, wrap_up_code):
        """
        Sets the wrap_up_code of this AnalyticsConversationSegment.


        :param wrap_up_code: The wrap_up_code of this AnalyticsConversationSegment.
        :type: str
        """
        self._wrap_up_code = wrap_up_code

    @property
    def wrap_up_note(self):
        """
        Gets the wrap_up_note of this AnalyticsConversationSegment.


        :return: The wrap_up_note of this AnalyticsConversationSegment.
        :rtype: str
        """
        return self._wrap_up_note

    @wrap_up_note.setter
    def wrap_up_note(self, wrap_up_note):
        """
        Sets the wrap_up_note of this AnalyticsConversationSegment.


        :param wrap_up_note: The wrap_up_note of this AnalyticsConversationSegment.
        :type: str
        """
        self._wrap_up_note = wrap_up_note

    @property
    def wrap_up_tags(self):
        """
        Gets the wrap_up_tags of this AnalyticsConversationSegment.


        :return: The wrap_up_tags of this AnalyticsConversationSegment.
        :rtype: list[str]
        """
        return self._wrap_up_tags

    @wrap_up_tags.setter
    def wrap_up_tags(self, wrap_up_tags):
        """
        Sets the wrap_up_tags of this AnalyticsConversationSegment.


        :param wrap_up_tags: The wrap_up_tags of this AnalyticsConversationSegment.
        :type: list[str]
        """
        self._wrap_up_tags = wrap_up_tags

    @property
    def error_code(self):
        """
        Gets the error_code of this AnalyticsConversationSegment.


        :return: The error_code of this AnalyticsConversationSegment.
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """
        Sets the error_code of this AnalyticsConversationSegment.


        :param error_code: The error_code of this AnalyticsConversationSegment.
        :type: str
        """
        self._error_code = error_code

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this AnalyticsConversationSegment.


        :return: The disconnect_type of this AnalyticsConversationSegment.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this AnalyticsConversationSegment.


        :param disconnect_type: The disconnect_type of this AnalyticsConversationSegment.
        :type: str
        """
        allowed_values = ["endpoint", "client", "system", "transfer", "error", "peer", "other", "spam", "transportFailure", "conferenceTransfer", "consultTransfer", "forwardTransfer"]
        if disconnect_type not in allowed_values:
            raise ValueError(
                "Invalid value for `disconnect_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._disconnect_type = disconnect_type

    @property
    def segment_type(self):
        """
        Gets the segment_type of this AnalyticsConversationSegment.


        :return: The segment_type of this AnalyticsConversationSegment.
        :rtype: str
        """
        return self._segment_type

    @segment_type.setter
    def segment_type(self, segment_type):
        """
        Sets the segment_type of this AnalyticsConversationSegment.


        :param segment_type: The segment_type of this AnalyticsConversationSegment.
        :type: str
        """
        allowed_values = ["unknown", "alert", "system", "delay", "hold", "interact", "ivr", "dialing", "wrapup", "voicemail"]
        if segment_type not in allowed_values:
            raise ValueError(
                "Invalid value for `segment_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._segment_type = segment_type

    @property
    def requested_routing_user_ids(self):
        """
        Gets the requested_routing_user_ids of this AnalyticsConversationSegment.


        :return: The requested_routing_user_ids of this AnalyticsConversationSegment.
        :rtype: list[str]
        """
        return self._requested_routing_user_ids

    @requested_routing_user_ids.setter
    def requested_routing_user_ids(self, requested_routing_user_ids):
        """
        Sets the requested_routing_user_ids of this AnalyticsConversationSegment.


        :param requested_routing_user_ids: The requested_routing_user_ids of this AnalyticsConversationSegment.
        :type: list[str]
        """
        self._requested_routing_user_ids = requested_routing_user_ids

    @property
    def requested_routing_skill_ids(self):
        """
        Gets the requested_routing_skill_ids of this AnalyticsConversationSegment.


        :return: The requested_routing_skill_ids of this AnalyticsConversationSegment.
        :rtype: list[str]
        """
        return self._requested_routing_skill_ids

    @requested_routing_skill_ids.setter
    def requested_routing_skill_ids(self, requested_routing_skill_ids):
        """
        Sets the requested_routing_skill_ids of this AnalyticsConversationSegment.


        :param requested_routing_skill_ids: The requested_routing_skill_ids of this AnalyticsConversationSegment.
        :type: list[str]
        """
        self._requested_routing_skill_ids = requested_routing_skill_ids

    @property
    def requested_language_id(self):
        """
        Gets the requested_language_id of this AnalyticsConversationSegment.


        :return: The requested_language_id of this AnalyticsConversationSegment.
        :rtype: str
        """
        return self._requested_language_id

    @requested_language_id.setter
    def requested_language_id(self, requested_language_id):
        """
        Sets the requested_language_id of this AnalyticsConversationSegment.


        :param requested_language_id: The requested_language_id of this AnalyticsConversationSegment.
        :type: str
        """
        self._requested_language_id = requested_language_id

    @property
    def properties(self):
        """
        Gets the properties of this AnalyticsConversationSegment.


        :return: The properties of this AnalyticsConversationSegment.
        :rtype: list[AnalyticsProperty]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this AnalyticsConversationSegment.


        :param properties: The properties of this AnalyticsConversationSegment.
        :type: list[AnalyticsProperty]
        """
        self._properties = properties

    @property
    def source_conversation_id(self):
        """
        Gets the source_conversation_id of this AnalyticsConversationSegment.


        :return: The source_conversation_id of this AnalyticsConversationSegment.
        :rtype: str
        """
        return self._source_conversation_id

    @source_conversation_id.setter
    def source_conversation_id(self, source_conversation_id):
        """
        Sets the source_conversation_id of this AnalyticsConversationSegment.


        :param source_conversation_id: The source_conversation_id of this AnalyticsConversationSegment.
        :type: str
        """
        self._source_conversation_id = source_conversation_id

    @property
    def destination_conversation_id(self):
        """
        Gets the destination_conversation_id of this AnalyticsConversationSegment.


        :return: The destination_conversation_id of this AnalyticsConversationSegment.
        :rtype: str
        """
        return self._destination_conversation_id

    @destination_conversation_id.setter
    def destination_conversation_id(self, destination_conversation_id):
        """
        Sets the destination_conversation_id of this AnalyticsConversationSegment.


        :param destination_conversation_id: The destination_conversation_id of this AnalyticsConversationSegment.
        :type: str
        """
        self._destination_conversation_id = destination_conversation_id

    @property
    def source_session_id(self):
        """
        Gets the source_session_id of this AnalyticsConversationSegment.


        :return: The source_session_id of this AnalyticsConversationSegment.
        :rtype: str
        """
        return self._source_session_id

    @source_session_id.setter
    def source_session_id(self, source_session_id):
        """
        Sets the source_session_id of this AnalyticsConversationSegment.


        :param source_session_id: The source_session_id of this AnalyticsConversationSegment.
        :type: str
        """
        self._source_session_id = source_session_id

    @property
    def destination_session_id(self):
        """
        Gets the destination_session_id of this AnalyticsConversationSegment.


        :return: The destination_session_id of this AnalyticsConversationSegment.
        :rtype: str
        """
        return self._destination_session_id

    @destination_session_id.setter
    def destination_session_id(self, destination_session_id):
        """
        Sets the destination_session_id of this AnalyticsConversationSegment.


        :param destination_session_id: The destination_session_id of this AnalyticsConversationSegment.
        :type: str
        """
        self._destination_session_id = destination_session_id

    @property
    def sip_response_codes(self):
        """
        Gets the sip_response_codes of this AnalyticsConversationSegment.


        :return: The sip_response_codes of this AnalyticsConversationSegment.
        :rtype: list[int]
        """
        return self._sip_response_codes

    @sip_response_codes.setter
    def sip_response_codes(self, sip_response_codes):
        """
        Sets the sip_response_codes of this AnalyticsConversationSegment.


        :param sip_response_codes: The sip_response_codes of this AnalyticsConversationSegment.
        :type: list[int]
        """
        self._sip_response_codes = sip_response_codes

    @property
    def q850_response_codes(self):
        """
        Gets the q850_response_codes of this AnalyticsConversationSegment.


        :return: The q850_response_codes of this AnalyticsConversationSegment.
        :rtype: list[int]
        """
        return self._q850_response_codes

    @q850_response_codes.setter
    def q850_response_codes(self, q850_response_codes):
        """
        Sets the q850_response_codes of this AnalyticsConversationSegment.


        :param q850_response_codes: The q850_response_codes of this AnalyticsConversationSegment.
        :type: list[int]
        """
        self._q850_response_codes = q850_response_codes

    @property
    def conference(self):
        """
        Gets the conference of this AnalyticsConversationSegment.


        :return: The conference of this AnalyticsConversationSegment.
        :rtype: bool
        """
        return self._conference

    @conference.setter
    def conference(self, conference):
        """
        Sets the conference of this AnalyticsConversationSegment.


        :param conference: The conference of this AnalyticsConversationSegment.
        :type: bool
        """
        self._conference = conference

    @property
    def group_id(self):
        """
        Gets the group_id of this AnalyticsConversationSegment.


        :return: The group_id of this AnalyticsConversationSegment.
        :rtype: str
        """
        return self._group_id

    @group_id.setter
    def group_id(self, group_id):
        """
        Sets the group_id of this AnalyticsConversationSegment.


        :param group_id: The group_id of this AnalyticsConversationSegment.
        :type: str
        """
        self._group_id = group_id

    @property
    def subject(self):
        """
        Gets the subject of this AnalyticsConversationSegment.


        :return: The subject of this AnalyticsConversationSegment.
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """
        Sets the subject of this AnalyticsConversationSegment.


        :param subject: The subject of this AnalyticsConversationSegment.
        :type: str
        """
        self._subject = subject

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class OutboundRoute(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        OutboundRoute - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'version': 'int',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'modified_by': 'str',
            'created_by': 'str',
            'state': 'str',
            'modified_by_app': 'str',
            'created_by_app': 'str',
            'site': 'Site',
            'classification_types': 'list[str]',
            'enabled': 'bool',
            'distribution': 'str',
            'managed': 'bool',
            'external_trunk_bases': 'list[UriReference]',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'version': 'version',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'modified_by': 'modifiedBy',
            'created_by': 'createdBy',
            'state': 'state',
            'modified_by_app': 'modifiedByApp',
            'created_by_app': 'createdByApp',
            'site': 'site',
            'classification_types': 'classificationTypes',
            'enabled': 'enabled',
            'distribution': 'distribution',
            'managed': 'managed',
            'external_trunk_bases': 'externalTrunkBases',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._version = None
        self._date_created = None
        self._date_modified = None
        self._modified_by = None
        self._created_by = None
        self._state = None
        self._modified_by_app = None
        self._created_by_app = None
        self._site = None
        self._classification_types = None
        self._enabled = False
        self._distribution = None
        self._managed = False
        self._external_trunk_bases = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this OutboundRoute.
        The globally unique identifier for the object.

        :return: The id of this OutboundRoute.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this OutboundRoute.
        The globally unique identifier for the object.

        :param id: The id of this OutboundRoute.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this OutboundRoute.


        :return: The name of this OutboundRoute.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this OutboundRoute.


        :param name: The name of this OutboundRoute.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this OutboundRoute.


        :return: The description of this OutboundRoute.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this OutboundRoute.


        :param description: The description of this OutboundRoute.
        :type: str
        """
        self._description = description

    @property
    def version(self):
        """
        Gets the version of this OutboundRoute.


        :return: The version of this OutboundRoute.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this OutboundRoute.


        :param version: The version of this OutboundRoute.
        :type: int
        """
        self._version = version

    @property
    def date_created(self):
        """
        Gets the date_created of this OutboundRoute.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_created of this OutboundRoute.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this OutboundRoute.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_created: The date_created of this OutboundRoute.
        :type: datetime
        """
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this OutboundRoute.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_modified of this OutboundRoute.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this OutboundRoute.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_modified: The date_modified of this OutboundRoute.
        :type: datetime
        """
        self._date_modified = date_modified

    @property
    def modified_by(self):
        """
        Gets the modified_by of this OutboundRoute.


        :return: The modified_by of this OutboundRoute.
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this OutboundRoute.


        :param modified_by: The modified_by of this OutboundRoute.
        :type: str
        """
        self._modified_by = modified_by

    @property
    def created_by(self):
        """
        Gets the created_by of this OutboundRoute.


        :return: The created_by of this OutboundRoute.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this OutboundRoute.


        :param created_by: The created_by of this OutboundRoute.
        :type: str
        """
        self._created_by = created_by

    @property
    def state(self):
        """
        Gets the state of this OutboundRoute.


        :return: The state of this OutboundRoute.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this OutboundRoute.


        :param state: The state of this OutboundRoute.
        :type: str
        """
        allowed_values = ["active", "inactive", "deleted"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )
        self._state = state

    @property
    def modified_by_app(self):
        """
        Gets the modified_by_app of this OutboundRoute.


        :return: The modified_by_app of this OutboundRoute.
        :rtype: str
        """
        return self._modified_by_app

    @modified_by_app.setter
    def modified_by_app(self, modified_by_app):
        """
        Sets the modified_by_app of this OutboundRoute.


        :param modified_by_app: The modified_by_app of this OutboundRoute.
        :type: str
        """
        self._modified_by_app = modified_by_app

    @property
    def created_by_app(self):
        """
        Gets the created_by_app of this OutboundRoute.


        :return: The created_by_app of this OutboundRoute.
        :rtype: str
        """
        return self._created_by_app

    @created_by_app.setter
    def created_by_app(self, created_by_app):
        """
        Sets the created_by_app of this OutboundRoute.


        :param created_by_app: The created_by_app of this OutboundRoute.
        :type: str
        """
        self._created_by_app = created_by_app

    @property
    def site(self):
        """
        Gets the site of this OutboundRoute.


        :return: The site of this OutboundRoute.
        :rtype: Site
        """
        return self._site

    @site.setter
    def site(self, site):
        """
        Sets the site of this OutboundRoute.


        :param site: The site of this OutboundRoute.
        :type: Site
        """
        self._site = site

    @property
    def classification_types(self):
        """
        Gets the classification_types of this OutboundRoute.


        :return: The classification_types of this OutboundRoute.
        :rtype: list[str]
        """
        return self._classification_types

    @classification_types.setter
    def classification_types(self, classification_types):
        """
        Sets the classification_types of this OutboundRoute.


        :param classification_types: The classification_types of this OutboundRoute.
        :type: list[str]
        """
        self._classification_types = classification_types

    @property
    def enabled(self):
        """
        Gets the enabled of this OutboundRoute.


        :return: The enabled of this OutboundRoute.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this OutboundRoute.


        :param enabled: The enabled of this OutboundRoute.
        :type: bool
        """
        self._enabled = enabled

    @property
    def distribution(self):
        """
        Gets the distribution of this OutboundRoute.


        :return: The distribution of this OutboundRoute.
        :rtype: str
        """
        return self._distribution

    @distribution.setter
    def distribution(self, distribution):
        """
        Sets the distribution of this OutboundRoute.


        :param distribution: The distribution of this OutboundRoute.
        :type: str
        """
        allowed_values = ["SEQUENTIAL", "RANDOM"]
        if distribution not in allowed_values:
            raise ValueError(
                "Invalid value for `distribution`, must be one of {0}"
                .format(allowed_values)
            )
        self._distribution = distribution

    @property
    def managed(self):
        """
        Gets the managed of this OutboundRoute.


        :return: The managed of this OutboundRoute.
        :rtype: bool
        """
        return self._managed

    @managed.setter
    def managed(self, managed):
        """
        Sets the managed of this OutboundRoute.


        :param managed: The managed of this OutboundRoute.
        :type: bool
        """
        self._managed = managed

    @property
    def external_trunk_bases(self):
        """
        Gets the external_trunk_bases of this OutboundRoute.
        Trunk base settings of trunkType \"EXTERNAL\".  This base must also be set on an edge logical interface for correct routing.

        :return: The external_trunk_bases of this OutboundRoute.
        :rtype: list[UriReference]
        """
        return self._external_trunk_bases

    @external_trunk_bases.setter
    def external_trunk_bases(self, external_trunk_bases):
        """
        Sets the external_trunk_bases of this OutboundRoute.
        Trunk base settings of trunkType \"EXTERNAL\".  This base must also be set on an edge logical interface for correct routing.

        :param external_trunk_bases: The external_trunk_bases of this OutboundRoute.
        :type: list[UriReference]
        """
        self._external_trunk_bases = external_trunk_bases

    @property
    def self_uri(self):
        """
        Gets the self_uri of this OutboundRoute.
        The URI for this object

        :return: The self_uri of this OutboundRoute.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this OutboundRoute.
        The URI for this object

        :param self_uri: The self_uri of this OutboundRoute.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class TransformEndpoint(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        TransformEndpoint - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'swagger_url': 'str',
            'route': 'str',
            'entity': 'str',
            'api_function': 'str',
            'ready': 'bool',
            'active': 'bool',
            'batch_size': 'int',
            'parallelism': 'int',
            'update_progress_every': 'int',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'swagger_url': 'swaggerUrl',
            'route': 'route',
            'entity': 'entity',
            'api_function': 'apiFunction',
            'ready': 'ready',
            'active': 'active',
            'batch_size': 'batchSize',
            'parallelism': 'parallelism',
            'update_progress_every': 'updateProgressEvery',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._swagger_url = None
        self._route = None
        self._entity = None
        self._api_function = None
        self._ready = False
        self._active = False
        self._batch_size = None
        self._parallelism = None
        self._update_progress_every = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this TransformEndpoint.
        The globally unique identifier for the object.

        :return: The id of this TransformEndpoint.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this TransformEndpoint.
        The globally unique identifier for the object.

        :param id: The id of this TransformEndpoint.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this TransformEndpoint.


        :return: The name of this TransformEndpoint.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this TransformEndpoint.


        :param name: The name of this TransformEndpoint.
        :type: str
        """
        self._name = name

    @property
    def swagger_url(self):
        """
        Gets the swagger_url of this TransformEndpoint.
        The Url to the swagger documentation of the endpoint where parsed entities will be posted

        :return: The swagger_url of this TransformEndpoint.
        :rtype: str
        """
        return self._swagger_url

    @swagger_url.setter
    def swagger_url(self, swagger_url):
        """
        Sets the swagger_url of this TransformEndpoint.
        The Url to the swagger documentation of the endpoint where parsed entities will be posted

        :param swagger_url: The swagger_url of this TransformEndpoint.
        :type: str
        """
        self._swagger_url = swagger_url

    @property
    def route(self):
        """
        Gets the route of this TransformEndpoint.
        The swagger route to use

        :return: The route of this TransformEndpoint.
        :rtype: str
        """
        return self._route

    @route.setter
    def route(self, route):
        """
        Sets the route of this TransformEndpoint.
        The swagger route to use

        :param route: The route of this TransformEndpoint.
        :type: str
        """
        self._route = route

    @property
    def entity(self):
        """
        Gets the entity of this TransformEndpoint.
        The entity type being posted

        :return: The entity of this TransformEndpoint.
        :rtype: str
        """
        return self._entity

    @entity.setter
    def entity(self, entity):
        """
        Sets the entity of this TransformEndpoint.
        The entity type being posted

        :param entity: The entity of this TransformEndpoint.
        :type: str
        """
        self._entity = entity

    @property
    def api_function(self):
        """
        Gets the api_function of this TransformEndpoint.
        The swagger function being called

        :return: The api_function of this TransformEndpoint.
        :rtype: str
        """
        return self._api_function

    @api_function.setter
    def api_function(self, api_function):
        """
        Sets the api_function of this TransformEndpoint.
        The swagger function being called

        :param api_function: The api_function of this TransformEndpoint.
        :type: str
        """
        self._api_function = api_function

    @property
    def ready(self):
        """
        Gets the ready of this TransformEndpoint.
        Whether this TransformEndpoint has been configured to work (security groups, permissions, etc)

        :return: The ready of this TransformEndpoint.
        :rtype: bool
        """
        return self._ready

    @ready.setter
    def ready(self, ready):
        """
        Sets the ready of this TransformEndpoint.
        Whether this TransformEndpoint has been configured to work (security groups, permissions, etc)

        :param ready: The ready of this TransformEndpoint.
        :type: bool
        """
        self._ready = ready

    @property
    def active(self):
        """
        Gets the active of this TransformEndpoint.
        Whether this TransformEndpoint is currently active and accepting transformation operations

        :return: The active of this TransformEndpoint.
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """
        Sets the active of this TransformEndpoint.
        Whether this TransformEndpoint is currently active and accepting transformation operations

        :param active: The active of this TransformEndpoint.
        :type: bool
        """
        self._active = active

    @property
    def batch_size(self):
        """
        Gets the batch_size of this TransformEndpoint.
        The number of entities to send in an array for batch POSTs, or 0 for unbatched POSTs

        :return: The batch_size of this TransformEndpoint.
        :rtype: int
        """
        return self._batch_size

    @batch_size.setter
    def batch_size(self, batch_size):
        """
        Sets the batch_size of this TransformEndpoint.
        The number of entities to send in an array for batch POSTs, or 0 for unbatched POSTs

        :param batch_size: The batch_size of this TransformEndpoint.
        :type: int
        """
        self._batch_size = batch_size

    @property
    def parallelism(self):
        """
        Gets the parallelism of this TransformEndpoint.
        The number of parallel POSTs to allow at once

        :return: The parallelism of this TransformEndpoint.
        :rtype: int
        """
        return self._parallelism

    @parallelism.setter
    def parallelism(self, parallelism):
        """
        Sets the parallelism of this TransformEndpoint.
        The number of parallel POSTs to allow at once

        :param parallelism: The parallelism of this TransformEndpoint.
        :type: int
        """
        self._parallelism = parallelism

    @property
    def update_progress_every(self):
        """
        Gets the update_progress_every of this TransformEndpoint.
        The swagger route to use

        :return: The update_progress_every of this TransformEndpoint.
        :rtype: int
        """
        return self._update_progress_every

    @update_progress_every.setter
    def update_progress_every(self, update_progress_every):
        """
        Sets the update_progress_every of this TransformEndpoint.
        The swagger route to use

        :param update_progress_every: The update_progress_every of this TransformEndpoint.
        :type: int
        """
        self._update_progress_every = update_progress_every

    @property
    def self_uri(self):
        """
        Gets the self_uri of this TransformEndpoint.
        The URI for this object

        :return: The self_uri of this TransformEndpoint.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this TransformEndpoint.
        The URI for this object

        :param self_uri: The self_uri of this TransformEndpoint.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class UserActionMetadataRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        UserActionMetadataRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'format': 'str',
            'method': 'str',
            'input_schema_uri': 'str',
            'success_schema_uri': 'str',
            'input_schema': 'object',
            'success_schema': 'object'
        }

        self.attribute_map = {
            'format': 'format',
            'method': 'method',
            'input_schema_uri': 'inputSchemaUri',
            'success_schema_uri': 'successSchemaUri',
            'input_schema': 'inputSchema',
            'success_schema': 'successSchema'
        }

        self._format = None
        self._method = None
        self._input_schema_uri = None
        self._success_schema_uri = None
        self._input_schema = None
        self._success_schema = None

    @property
    def format(self):
        """
        Gets the format of this UserActionMetadataRequest.


        :return: The format of this UserActionMetadataRequest.
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """
        Sets the format of this UserActionMetadataRequest.


        :param format: The format of this UserActionMetadataRequest.
        :type: str
        """
        self._format = format

    @property
    def method(self):
        """
        Gets the method of this UserActionMetadataRequest.


        :return: The method of this UserActionMetadataRequest.
        :rtype: str
        """
        return self._method

    @method.setter
    def method(self, method):
        """
        Sets the method of this UserActionMetadataRequest.


        :param method: The method of this UserActionMetadataRequest.
        :type: str
        """
        self._method = method

    @property
    def input_schema_uri(self):
        """
        Gets the input_schema_uri of this UserActionMetadataRequest.


        :return: The input_schema_uri of this UserActionMetadataRequest.
        :rtype: str
        """
        return self._input_schema_uri

    @input_schema_uri.setter
    def input_schema_uri(self, input_schema_uri):
        """
        Sets the input_schema_uri of this UserActionMetadataRequest.


        :param input_schema_uri: The input_schema_uri of this UserActionMetadataRequest.
        :type: str
        """
        self._input_schema_uri = input_schema_uri

    @property
    def success_schema_uri(self):
        """
        Gets the success_schema_uri of this UserActionMetadataRequest.


        :return: The success_schema_uri of this UserActionMetadataRequest.
        :rtype: str
        """
        return self._success_schema_uri

    @success_schema_uri.setter
    def success_schema_uri(self, success_schema_uri):
        """
        Sets the success_schema_uri of this UserActionMetadataRequest.


        :param success_schema_uri: The success_schema_uri of this UserActionMetadataRequest.
        :type: str
        """
        self._success_schema_uri = success_schema_uri

    @property
    def input_schema(self):
        """
        Gets the input_schema of this UserActionMetadataRequest.


        :return: The input_schema of this UserActionMetadataRequest.
        :rtype: object
        """
        return self._input_schema

    @input_schema.setter
    def input_schema(self, input_schema):
        """
        Sets the input_schema of this UserActionMetadataRequest.


        :param input_schema: The input_schema of this UserActionMetadataRequest.
        :type: object
        """
        self._input_schema = input_schema

    @property
    def success_schema(self):
        """
        Gets the success_schema of this UserActionMetadataRequest.


        :return: The success_schema of this UserActionMetadataRequest.
        :rtype: object
        """
        return self._success_schema

    @success_schema.setter
    def success_schema(self, success_schema):
        """
        Sets the success_schema of this UserActionMetadataRequest.


        :param success_schema: The success_schema of this UserActionMetadataRequest.
        :type: object
        """
        self._success_schema = success_schema

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class Recording(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Recording - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'conversation_id': 'str',
            'path': 'str',
            'start_time': 'str',
            'end_time': 'str',
            'media': 'str',
            'annotations': 'list[Annotation]',
            'transcript': 'list[ChatMessage]',
            'email_transcript': 'list[RecordingEmailMessage]',
            'file_state': 'str',
            'restore_expiration_time': 'datetime',
            'media_uris': 'dict(str, MediaResult)',
            'estimated_transcode_time_ms': 'int',
            'actual_transcode_time_ms': 'int',
            'archive_date': 'datetime',
            'archive_medium': 'str',
            'delete_date': 'datetime',
            'max_allowed_restorations_for_org': 'int',
            'remaining_restorations_allowed_for_org': 'int',
            'session_id': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'conversation_id': 'conversationId',
            'path': 'path',
            'start_time': 'startTime',
            'end_time': 'endTime',
            'media': 'media',
            'annotations': 'annotations',
            'transcript': 'transcript',
            'email_transcript': 'emailTranscript',
            'file_state': 'fileState',
            'restore_expiration_time': 'restoreExpirationTime',
            'media_uris': 'mediaUris',
            'estimated_transcode_time_ms': 'estimatedTranscodeTimeMs',
            'actual_transcode_time_ms': 'actualTranscodeTimeMs',
            'archive_date': 'archiveDate',
            'archive_medium': 'archiveMedium',
            'delete_date': 'deleteDate',
            'max_allowed_restorations_for_org': 'maxAllowedRestorationsForOrg',
            'remaining_restorations_allowed_for_org': 'remainingRestorationsAllowedForOrg',
            'session_id': 'sessionId',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._conversation_id = None
        self._path = None
        self._start_time = None
        self._end_time = None
        self._media = None
        self._annotations = None
        self._transcript = None
        self._email_transcript = None
        self._file_state = None
        self._restore_expiration_time = None
        self._media_uris = None
        self._estimated_transcode_time_ms = None
        self._actual_transcode_time_ms = None
        self._archive_date = None
        self._archive_medium = None
        self._delete_date = None
        self._max_allowed_restorations_for_org = None
        self._remaining_restorations_allowed_for_org = None
        self._session_id = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Recording.
        The globally unique identifier for the object.

        :return: The id of this Recording.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Recording.
        The globally unique identifier for the object.

        :param id: The id of this Recording.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Recording.


        :return: The name of this Recording.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Recording.


        :param name: The name of this Recording.
        :type: str
        """
        self._name = name

    @property
    def conversation_id(self):
        """
        Gets the conversation_id of this Recording.


        :return: The conversation_id of this Recording.
        :rtype: str
        """
        return self._conversation_id

    @conversation_id.setter
    def conversation_id(self, conversation_id):
        """
        Sets the conversation_id of this Recording.


        :param conversation_id: The conversation_id of this Recording.
        :type: str
        """
        self._conversation_id = conversation_id

    @property
    def path(self):
        """
        Gets the path of this Recording.


        :return: The path of this Recording.
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this Recording.


        :param path: The path of this Recording.
        :type: str
        """
        self._path = path

    @property
    def start_time(self):
        """
        Gets the start_time of this Recording.


        :return: The start_time of this Recording.
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this Recording.


        :param start_time: The start_time of this Recording.
        :type: str
        """
        self._start_time = start_time

    @property
    def end_time(self):
        """
        Gets the end_time of this Recording.


        :return: The end_time of this Recording.
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this Recording.


        :param end_time: The end_time of this Recording.
        :type: str
        """
        self._end_time = end_time

    @property
    def media(self):
        """
        Gets the media of this Recording.
        The type of media that the recording is.

        :return: The media of this Recording.
        :rtype: str
        """
        return self._media

    @media.setter
    def media(self, media):
        """
        Sets the media of this Recording.
        The type of media that the recording is.

        :param media: The media of this Recording.
        :type: str
        """
        self._media = media

    @property
    def annotations(self):
        """
        Gets the annotations of this Recording.
        Annotations that belong to the recording.

        :return: The annotations of this Recording.
        :rtype: list[Annotation]
        """
        return self._annotations

    @annotations.setter
    def annotations(self, annotations):
        """
        Sets the annotations of this Recording.
        Annotations that belong to the recording.

        :param annotations: The annotations of this Recording.
        :type: list[Annotation]
        """
        self._annotations = annotations

    @property
    def transcript(self):
        """
        Gets the transcript of this Recording.
        Represents a chat transcript

        :return: The transcript of this Recording.
        :rtype: list[ChatMessage]
        """
        return self._transcript

    @transcript.setter
    def transcript(self, transcript):
        """
        Sets the transcript of this Recording.
        Represents a chat transcript

        :param transcript: The transcript of this Recording.
        :type: list[ChatMessage]
        """
        self._transcript = transcript

    @property
    def email_transcript(self):
        """
        Gets the email_transcript of this Recording.
        Represents an email transcript

        :return: The email_transcript of this Recording.
        :rtype: list[RecordingEmailMessage]
        """
        return self._email_transcript

    @email_transcript.setter
    def email_transcript(self, email_transcript):
        """
        Sets the email_transcript of this Recording.
        Represents an email transcript

        :param email_transcript: The email_transcript of this Recording.
        :type: list[RecordingEmailMessage]
        """
        self._email_transcript = email_transcript

    @property
    def file_state(self):
        """
        Gets the file_state of this Recording.
        Represents the current file state for a recording. Examples: Uploading, Archived, etc

        :return: The file_state of this Recording.
        :rtype: str
        """
        return self._file_state

    @file_state.setter
    def file_state(self, file_state):
        """
        Sets the file_state of this Recording.
        Represents the current file state for a recording. Examples: Uploading, Archived, etc

        :param file_state: The file_state of this Recording.
        :type: str
        """
        allowed_values = ["ARCHIVED", "AVAILABLE", "DELETED", "RESTORED", "RESTORING", "UPLOADING"]
        if file_state not in allowed_values:
            raise ValueError(
                "Invalid value for `file_state`, must be one of {0}"
                .format(allowed_values)
            )
        self._file_state = file_state

    @property
    def restore_expiration_time(self):
        """
        Gets the restore_expiration_time of this Recording.
        The amount of time a restored recording will remain restored before being archived again. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The restore_expiration_time of this Recording.
        :rtype: datetime
        """
        return self._restore_expiration_time

    @restore_expiration_time.setter
    def restore_expiration_time(self, restore_expiration_time):
        """
        Sets the restore_expiration_time of this Recording.
        The amount of time a restored recording will remain restored before being archived again. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param restore_expiration_time: The restore_expiration_time of this Recording.
        :type: datetime
        """
        self._restore_expiration_time = restore_expiration_time

    @property
    def media_uris(self):
        """
        Gets the media_uris of this Recording.
        The different mediaUris for the recording.

        :return: The media_uris of this Recording.
        :rtype: dict(str, MediaResult)
        """
        return self._media_uris

    @media_uris.setter
    def media_uris(self, media_uris):
        """
        Sets the media_uris of this Recording.
        The different mediaUris for the recording.

        :param media_uris: The media_uris of this Recording.
        :type: dict(str, MediaResult)
        """
        self._media_uris = media_uris

    @property
    def estimated_transcode_time_ms(self):
        """
        Gets the estimated_transcode_time_ms of this Recording.


        :return: The estimated_transcode_time_ms of this Recording.
        :rtype: int
        """
        return self._estimated_transcode_time_ms

    @estimated_transcode_time_ms.setter
    def estimated_transcode_time_ms(self, estimated_transcode_time_ms):
        """
        Sets the estimated_transcode_time_ms of this Recording.


        :param estimated_transcode_time_ms: The estimated_transcode_time_ms of this Recording.
        :type: int
        """
        self._estimated_transcode_time_ms = estimated_transcode_time_ms

    @property
    def actual_transcode_time_ms(self):
        """
        Gets the actual_transcode_time_ms of this Recording.


        :return: The actual_transcode_time_ms of this Recording.
        :rtype: int
        """
        return self._actual_transcode_time_ms

    @actual_transcode_time_ms.setter
    def actual_transcode_time_ms(self, actual_transcode_time_ms):
        """
        Sets the actual_transcode_time_ms of this Recording.


        :param actual_transcode_time_ms: The actual_transcode_time_ms of this Recording.
        :type: int
        """
        self._actual_transcode_time_ms = actual_transcode_time_ms

    @property
    def archive_date(self):
        """
        Gets the archive_date of this Recording.
        The date the recording will be archived. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The archive_date of this Recording.
        :rtype: datetime
        """
        return self._archive_date

    @archive_date.setter
    def archive_date(self, archive_date):
        """
        Sets the archive_date of this Recording.
        The date the recording will be archived. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param archive_date: The archive_date of this Recording.
        :type: datetime
        """
        self._archive_date = archive_date

    @property
    def archive_medium(self):
        """
        Gets the archive_medium of this Recording.
        The type of archive medium used. Example: CloudArchive

        :return: The archive_medium of this Recording.
        :rtype: str
        """
        return self._archive_medium

    @archive_medium.setter
    def archive_medium(self, archive_medium):
        """
        Sets the archive_medium of this Recording.
        The type of archive medium used. Example: CloudArchive

        :param archive_medium: The archive_medium of this Recording.
        :type: str
        """
        allowed_values = ["CLOUDARCHIVE"]
        if archive_medium not in allowed_values:
            raise ValueError(
                "Invalid value for `archive_medium`, must be one of {0}"
                .format(allowed_values)
            )
        self._archive_medium = archive_medium

    @property
    def delete_date(self):
        """
        Gets the delete_date of this Recording.
        The date the recording will be deleted. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The delete_date of this Recording.
        :rtype: datetime
        """
        return self._delete_date

    @delete_date.setter
    def delete_date(self, delete_date):
        """
        Sets the delete_date of this Recording.
        The date the recording will be deleted. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param delete_date: The delete_date of this Recording.
        :type: datetime
        """
        self._delete_date = delete_date

    @property
    def max_allowed_restorations_for_org(self):
        """
        Gets the max_allowed_restorations_for_org of this Recording.
        How many archive restorations the organization is allowed to have.

        :return: The max_allowed_restorations_for_org of this Recording.
        :rtype: int
        """
        return self._max_allowed_restorations_for_org

    @max_allowed_restorations_for_org.setter
    def max_allowed_restorations_for_org(self, max_allowed_restorations_for_org):
        """
        Sets the max_allowed_restorations_for_org of this Recording.
        How many archive restorations the organization is allowed to have.

        :param max_allowed_restorations_for_org: The max_allowed_restorations_for_org of this Recording.
        :type: int
        """
        self._max_allowed_restorations_for_org = max_allowed_restorations_for_org

    @property
    def remaining_restorations_allowed_for_org(self):
        """
        Gets the remaining_restorations_allowed_for_org of this Recording.
        The remaining archive restorations the organization has.

        :return: The remaining_restorations_allowed_for_org of this Recording.
        :rtype: int
        """
        return self._remaining_restorations_allowed_for_org

    @remaining_restorations_allowed_for_org.setter
    def remaining_restorations_allowed_for_org(self, remaining_restorations_allowed_for_org):
        """
        Sets the remaining_restorations_allowed_for_org of this Recording.
        The remaining archive restorations the organization has.

        :param remaining_restorations_allowed_for_org: The remaining_restorations_allowed_for_org of this Recording.
        :type: int
        """
        self._remaining_restorations_allowed_for_org = remaining_restorations_allowed_for_org

    @property
    def session_id(self):
        """
        Gets the session_id of this Recording.
        The session id represents an external resource id, such as email, call, chat, etc

        :return: The session_id of this Recording.
        :rtype: str
        """
        return self._session_id

    @session_id.setter
    def session_id(self, session_id):
        """
        Sets the session_id of this Recording.
        The session id represents an external resource id, such as email, call, chat, etc

        :param session_id: The session_id of this Recording.
        :type: str
        """
        self._session_id = session_id

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Recording.
        The URI for this object

        :return: The self_uri of this Recording.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Recording.
        The URI for this object

        :param self_uri: The self_uri of this Recording.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class Line(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Line - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'version': 'int',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'modified_by': 'str',
            'created_by': 'str',
            'state': 'str',
            'modified_by_app': 'str',
            'created_by_app': 'str',
            'properties': 'dict(str, object)',
            'edge_group': 'UriReference',
            'template': 'UriReference',
            'site': 'UriReference',
            'line_base_settings': 'UriReference',
            'primary_edge': 'Edge',
            'secondary_edge': 'Edge',
            'logged_in_user': 'UriReference',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'version': 'version',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'modified_by': 'modifiedBy',
            'created_by': 'createdBy',
            'state': 'state',
            'modified_by_app': 'modifiedByApp',
            'created_by_app': 'createdByApp',
            'properties': 'properties',
            'edge_group': 'edgeGroup',
            'template': 'template',
            'site': 'site',
            'line_base_settings': 'lineBaseSettings',
            'primary_edge': 'primaryEdge',
            'secondary_edge': 'secondaryEdge',
            'logged_in_user': 'loggedInUser',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._version = None
        self._date_created = None
        self._date_modified = None
        self._modified_by = None
        self._created_by = None
        self._state = None
        self._modified_by_app = None
        self._created_by_app = None
        self._properties = None
        self._edge_group = None
        self._template = None
        self._site = None
        self._line_base_settings = None
        self._primary_edge = None
        self._secondary_edge = None
        self._logged_in_user = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Line.
        The globally unique identifier for the object.

        :return: The id of this Line.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Line.
        The globally unique identifier for the object.

        :param id: The id of this Line.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Line.


        :return: The name of this Line.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Line.


        :param name: The name of this Line.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this Line.


        :return: The description of this Line.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Line.


        :param description: The description of this Line.
        :type: str
        """
        self._description = description

    @property
    def version(self):
        """
        Gets the version of this Line.


        :return: The version of this Line.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this Line.


        :param version: The version of this Line.
        :type: int
        """
        self._version = version

    @property
    def date_created(self):
        """
        Gets the date_created of this Line.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_created of this Line.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this Line.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_created: The date_created of this Line.
        :type: datetime
        """
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this Line.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_modified of this Line.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this Line.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_modified: The date_modified of this Line.
        :type: datetime
        """
        self._date_modified = date_modified

    @property
    def modified_by(self):
        """
        Gets the modified_by of this Line.


        :return: The modified_by of this Line.
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this Line.


        :param modified_by: The modified_by of this Line.
        :type: str
        """
        self._modified_by = modified_by

    @property
    def created_by(self):
        """
        Gets the created_by of this Line.


        :return: The created_by of this Line.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this Line.


        :param created_by: The created_by of this Line.
        :type: str
        """
        self._created_by = created_by

    @property
    def state(self):
        """
        Gets the state of this Line.


        :return: The state of this Line.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this Line.


        :param state: The state of this Line.
        :type: str
        """
        allowed_values = ["active", "inactive", "deleted"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )
        self._state = state

    @property
    def modified_by_app(self):
        """
        Gets the modified_by_app of this Line.


        :return: The modified_by_app of this Line.
        :rtype: str
        """
        return self._modified_by_app

    @modified_by_app.setter
    def modified_by_app(self, modified_by_app):
        """
        Sets the modified_by_app of this Line.


        :param modified_by_app: The modified_by_app of this Line.
        :type: str
        """
        self._modified_by_app = modified_by_app

    @property
    def created_by_app(self):
        """
        Gets the created_by_app of this Line.


        :return: The created_by_app of this Line.
        :rtype: str
        """
        return self._created_by_app

    @created_by_app.setter
    def created_by_app(self, created_by_app):
        """
        Sets the created_by_app of this Line.


        :param created_by_app: The created_by_app of this Line.
        :type: str
        """
        self._created_by_app = created_by_app

    @property
    def properties(self):
        """
        Gets the properties of this Line.


        :return: The properties of this Line.
        :rtype: dict(str, object)
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this Line.


        :param properties: The properties of this Line.
        :type: dict(str, object)
        """
        self._properties = properties

    @property
    def edge_group(self):
        """
        Gets the edge_group of this Line.


        :return: The edge_group of this Line.
        :rtype: UriReference
        """
        return self._edge_group

    @edge_group.setter
    def edge_group(self, edge_group):
        """
        Sets the edge_group of this Line.


        :param edge_group: The edge_group of this Line.
        :type: UriReference
        """
        self._edge_group = edge_group

    @property
    def template(self):
        """
        Gets the template of this Line.


        :return: The template of this Line.
        :rtype: UriReference
        """
        return self._template

    @template.setter
    def template(self, template):
        """
        Sets the template of this Line.


        :param template: The template of this Line.
        :type: UriReference
        """
        self._template = template

    @property
    def site(self):
        """
        Gets the site of this Line.


        :return: The site of this Line.
        :rtype: UriReference
        """
        return self._site

    @site.setter
    def site(self, site):
        """
        Sets the site of this Line.


        :param site: The site of this Line.
        :type: UriReference
        """
        self._site = site

    @property
    def line_base_settings(self):
        """
        Gets the line_base_settings of this Line.


        :return: The line_base_settings of this Line.
        :rtype: UriReference
        """
        return self._line_base_settings

    @line_base_settings.setter
    def line_base_settings(self, line_base_settings):
        """
        Sets the line_base_settings of this Line.


        :param line_base_settings: The line_base_settings of this Line.
        :type: UriReference
        """
        self._line_base_settings = line_base_settings

    @property
    def primary_edge(self):
        """
        Gets the primary_edge of this Line.


        :return: The primary_edge of this Line.
        :rtype: Edge
        """
        return self._primary_edge

    @primary_edge.setter
    def primary_edge(self, primary_edge):
        """
        Sets the primary_edge of this Line.


        :param primary_edge: The primary_edge of this Line.
        :type: Edge
        """
        self._primary_edge = primary_edge

    @property
    def secondary_edge(self):
        """
        Gets the secondary_edge of this Line.


        :return: The secondary_edge of this Line.
        :rtype: Edge
        """
        return self._secondary_edge

    @secondary_edge.setter
    def secondary_edge(self, secondary_edge):
        """
        Sets the secondary_edge of this Line.


        :param secondary_edge: The secondary_edge of this Line.
        :type: Edge
        """
        self._secondary_edge = secondary_edge

    @property
    def logged_in_user(self):
        """
        Gets the logged_in_user of this Line.


        :return: The logged_in_user of this Line.
        :rtype: UriReference
        """
        return self._logged_in_user

    @logged_in_user.setter
    def logged_in_user(self, logged_in_user):
        """
        Sets the logged_in_user of this Line.


        :param logged_in_user: The logged_in_user of this Line.
        :type: UriReference
        """
        self._logged_in_user = logged_in_user

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Line.
        The URI for this object

        :return: The self_uri of this Line.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Line.
        The URI for this object

        :param self_uri: The self_uri of this Line.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class Trunk(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Trunk - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'version': 'int',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'modified_by': 'str',
            'created_by': 'str',
            'state': 'str',
            'modified_by_app': 'str',
            'created_by_app': 'str',
            'trunk_type': 'str',
            'edge': 'UriReference',
            'trunk_base': 'UriReference',
            'trunk_metabase': 'UriReference',
            'edge_group': 'UriReference',
            'enabled': 'bool',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'version': 'version',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'modified_by': 'modifiedBy',
            'created_by': 'createdBy',
            'state': 'state',
            'modified_by_app': 'modifiedByApp',
            'created_by_app': 'createdByApp',
            'trunk_type': 'trunkType',
            'edge': 'edge',
            'trunk_base': 'trunkBase',
            'trunk_metabase': 'trunkMetabase',
            'edge_group': 'edgeGroup',
            'enabled': 'enabled',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._version = None
        self._date_created = None
        self._date_modified = None
        self._modified_by = None
        self._created_by = None
        self._state = None
        self._modified_by_app = None
        self._created_by_app = None
        self._trunk_type = None
        self._edge = None
        self._trunk_base = None
        self._trunk_metabase = None
        self._edge_group = None
        self._enabled = False
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Trunk.
        The globally unique identifier for the object.

        :return: The id of this Trunk.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Trunk.
        The globally unique identifier for the object.

        :param id: The id of this Trunk.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Trunk.


        :return: The name of this Trunk.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Trunk.


        :param name: The name of this Trunk.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this Trunk.


        :return: The description of this Trunk.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Trunk.


        :param description: The description of this Trunk.
        :type: str
        """
        self._description = description

    @property
    def version(self):
        """
        Gets the version of this Trunk.


        :return: The version of this Trunk.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this Trunk.


        :param version: The version of this Trunk.
        :type: int
        """
        self._version = version

    @property
    def date_created(self):
        """
        Gets the date_created of this Trunk.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_created of this Trunk.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this Trunk.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_created: The date_created of this Trunk.
        :type: datetime
        """
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this Trunk.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_modified of this Trunk.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this Trunk.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_modified: The date_modified of this Trunk.
        :type: datetime
        """
        self._date_modified = date_modified

    @property
    def modified_by(self):
        """
        Gets the modified_by of this Trunk.


        :return: The modified_by of this Trunk.
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this Trunk.


        :param modified_by: The modified_by of this Trunk.
        :type: str
        """
        self._modified_by = modified_by

    @property
    def created_by(self):
        """
        Gets the created_by of this Trunk.


        :return: The created_by of this Trunk.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this Trunk.


        :param created_by: The created_by of this Trunk.
        :type: str
        """
        self._created_by = created_by

    @property
    def state(self):
        """
        Gets the state of this Trunk.


        :return: The state of this Trunk.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this Trunk.


        :param state: The state of this Trunk.
        :type: str
        """
        allowed_values = ["active", "inactive", "deleted"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )
        self._state = state

    @property
    def modified_by_app(self):
        """
        Gets the modified_by_app of this Trunk.


        :return: The modified_by_app of this Trunk.
        :rtype: str
        """
        return self._modified_by_app

    @modified_by_app.setter
    def modified_by_app(self, modified_by_app):
        """
        Sets the modified_by_app of this Trunk.


        :param modified_by_app: The modified_by_app of this Trunk.
        :type: str
        """
        self._modified_by_app = modified_by_app

    @property
    def created_by_app(self):
        """
        Gets the created_by_app of this Trunk.


        :return: The created_by_app of this Trunk.
        :rtype: str
        """
        return self._created_by_app

    @created_by_app.setter
    def created_by_app(self, created_by_app):
        """
        Sets the created_by_app of this Trunk.


        :param created_by_app: The created_by_app of this Trunk.
        :type: str
        """
        self._created_by_app = created_by_app

    @property
    def trunk_type(self):
        """
        Gets the trunk_type of this Trunk.
        The type of this trunk.

        :return: The trunk_type of this Trunk.
        :rtype: str
        """
        return self._trunk_type

    @trunk_type.setter
    def trunk_type(self, trunk_type):
        """
        Sets the trunk_type of this Trunk.
        The type of this trunk.

        :param trunk_type: The trunk_type of this Trunk.
        :type: str
        """
        allowed_values = ["EXTERNAL", "PHONE", "EDGE"]
        if trunk_type not in allowed_values:
            raise ValueError(
                "Invalid value for `trunk_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._trunk_type = trunk_type

    @property
    def edge(self):
        """
        Gets the edge of this Trunk.
        The Edge using this trunk.

        :return: The edge of this Trunk.
        :rtype: UriReference
        """
        return self._edge

    @edge.setter
    def edge(self, edge):
        """
        Sets the edge of this Trunk.
        The Edge using this trunk.

        :param edge: The edge of this Trunk.
        :type: UriReference
        """
        self._edge = edge

    @property
    def trunk_base(self):
        """
        Gets the trunk_base of this Trunk.
        The trunk base configuration used on this trunk.

        :return: The trunk_base of this Trunk.
        :rtype: UriReference
        """
        return self._trunk_base

    @trunk_base.setter
    def trunk_base(self, trunk_base):
        """
        Sets the trunk_base of this Trunk.
        The trunk base configuration used on this trunk.

        :param trunk_base: The trunk_base of this Trunk.
        :type: UriReference
        """
        self._trunk_base = trunk_base

    @property
    def trunk_metabase(self):
        """
        Gets the trunk_metabase of this Trunk.
        The metabase used to create this trunk.

        :return: The trunk_metabase of this Trunk.
        :rtype: UriReference
        """
        return self._trunk_metabase

    @trunk_metabase.setter
    def trunk_metabase(self, trunk_metabase):
        """
        Sets the trunk_metabase of this Trunk.
        The metabase used to create this trunk.

        :param trunk_metabase: The trunk_metabase of this Trunk.
        :type: UriReference
        """
        self._trunk_metabase = trunk_metabase

    @property
    def edge_group(self):
        """
        Gets the edge_group of this Trunk.
        The edge group associated with this trunk.

        :return: The edge_group of this Trunk.
        :rtype: UriReference
        """
        return self._edge_group

    @edge_group.setter
    def edge_group(self, edge_group):
        """
        Sets the edge_group of this Trunk.
        The edge group associated with this trunk.

        :param edge_group: The edge_group of this Trunk.
        :type: UriReference
        """
        self._edge_group = edge_group

    @property
    def enabled(self):
        """
        Gets the enabled of this Trunk.
        True if this trunk is in-service.  This comes from the trunk_enabled property of the referenced trunk base.

        :return: The enabled of this Trunk.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this Trunk.
        True if this trunk is in-service.  This comes from the trunk_enabled property of the referenced trunk base.

        :param enabled: The enabled of this Trunk.
        :type: bool
        """
        self._enabled = enabled

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Trunk.
        The URI for this object

        :return: The self_uri of this Trunk.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Trunk.
        The URI for this object

        :param self_uri: The self_uri of this Trunk.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class WorkItem(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WorkItem - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'work_item_exec_id': 'str',
            'work_item_config_id': 'str',
            'work_item_name': 'str'
        }

        self.attribute_map = {
            'work_item_exec_id': 'workItemExecId',
            'work_item_config_id': 'workItemConfigId',
            'work_item_name': 'workItemName'
        }

        self._work_item_exec_id = None
        self._work_item_config_id = None
        self._work_item_name = None

    @property
    def work_item_exec_id(self):
        """
        Gets the work_item_exec_id of this WorkItem.
        The work item execution id.

        :return: The work_item_exec_id of this WorkItem.
        :rtype: str
        """
        return self._work_item_exec_id

    @work_item_exec_id.setter
    def work_item_exec_id(self, work_item_exec_id):
        """
        Sets the work_item_exec_id of this WorkItem.
        The work item execution id.

        :param work_item_exec_id: The work_item_exec_id of this WorkItem.
        :type: str
        """
        self._work_item_exec_id = work_item_exec_id

    @property
    def work_item_config_id(self):
        """
        Gets the work_item_config_id of this WorkItem.
        The work item definition id.

        :return: The work_item_config_id of this WorkItem.
        :rtype: str
        """
        return self._work_item_config_id

    @work_item_config_id.setter
    def work_item_config_id(self, work_item_config_id):
        """
        Sets the work_item_config_id of this WorkItem.
        The work item definition id.

        :param work_item_config_id: The work_item_config_id of this WorkItem.
        :type: str
        """
        self._work_item_config_id = work_item_config_id

    @property
    def work_item_name(self):
        """
        Gets the work_item_name of this WorkItem.
        The work item displayable name.

        :return: The work_item_name of this WorkItem.
        :rtype: str
        """
        return self._work_item_name

    @work_item_name.setter
    def work_item_name(self, work_item_name):
        """
        Sets the work_item_name of this WorkItem.
        The work item displayable name.

        :param work_item_name: The work_item_name of this WorkItem.
        :type: str
        """
        self._work_item_name = work_item_name

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

